@@ -44,13 +44,13 @@ add_nyx_field = KnownNyxFields.add_field
 # Density
 add_nyx_field("density", function=lambda a, b: None, take_log=True,
           validators=[ValidateDataField("density")],
-          units=r"\rm{g}} / \rm{cm}^3",
-          projected_units =r"\rm{g}} / \rm{cm}^2")
-KnownNyxFields["density"]._projected_units =r"\rm{g}} / \rm{cm}^2"
+          units=r"\rm{g} / \rm{cm}^3",
+          projected_units =r"\rm{g} / \rm{cm}^2")
+KnownNyxFields["density"]._projected_units =r"\rm{g} / \rm{cm}^2"
 
 add_field("Density", function=TranslationFunc("density"), take_log=True,
-          units=r"\rm{g}} / \rm{cm}^3",
-          projected_units =r"\rm{g}} / \rm{cm}^2")
+          units=r"\rm{g} / \rm{cm}^3",
+          projected_units =r"\rm{g} / \rm{cm}^2")
 
 # Particle mass in units of $ M_{\odot}
 def _convertParticleMassMsun(data):
@@ -64,8 +64,8 @@ add_field("ParticleMassMsun", function=_particle_mass_m_sun,
           
 add_nyx_field("Dark_Matter_Density", function=TranslationFunc("particle_mass_density"),
           take_log=True,
-          units=r"\rm{g}} / \rm{cm}^3",particle_type=True,
-          projected_units =r"\rm{g}} / \rm{cm}^2")
+          units=r"\rm{g} / \rm{cm}^3",particle_type=True,
+          projected_units =r"\rm{g} / \rm{cm}^2")
 
 
 # Energy Density
