@@ -48,7 +48,8 @@ x_names = ['y','x','x']
 y_names = ['z','z','y']
 
 # How many of each thing are in an Mpc
-mpc_conversion = {'mpc'   : mpc_per_mpc,
+mpc_conversion = {'Mpc'   : mpc_per_mpc,
+                  'mpc'   : mpc_per_mpc,
                   'kpc'   : kpc_per_mpc,
                   'pc'    : pc_per_mpc,
                   'au'    : au_per_mpc,
@@ -56,7 +57,7 @@ mpc_conversion = {'mpc'   : mpc_per_mpc,
                   'miles' : miles_per_mpc,
                   'cm'    : cm_per_mpc}
 
-# How many seconds are in each thig
+# How many seconds are in each thing
 sec_conversion = {'Gyr'   : sec_per_Gyr,
                   'Myr'   : sec_per_Myr,
                   'years' : sec_per_year,
