@@ -107,36 +107,36 @@ def configuration(parent_package='',top_path=None):
     # https://bugzilla.redhat.com/show_bug.cgi?id=494579 ) we simply disable
     # support for setjmp.
     config.add_extension("CICDeposit", 
-                ["yt/utilities/lib/CICDeposit.c"],
+                ["yt/utilities/lib/CICDeposit.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("ContourFinding", 
-                ["yt/utilities/lib/ContourFinding.c",
+                ["yt/utilities/lib/ContourFinding.pyx",
                  "yt/utilities/lib/union_find.c"],
                 include_dirs=["yt/utilities/lib/"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("DepthFirstOctree", 
-                ["yt/utilities/lib/DepthFirstOctree.c"],
+                ["yt/utilities/lib/DepthFirstOctree.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("fortran_reader", 
-                ["yt/utilities/lib/fortran_reader.c"],
+                ["yt/utilities/lib/fortran_reader.pyx"],
                 include_dirs=["yt/utilities/lib/"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("freetype_writer", 
-                ["yt/utilities/lib/freetype_writer.c"],
+                ["yt/utilities/lib/freetype_writer.pyx"],
                 include_dirs = [freetype_inc,os.path.join(freetype_inc, "freetype2"),
                                 "yt/utilities/lib"],
                 library_dirs = [freetype_lib], libraries=["freetype"],
                 depends=["yt/utilities/lib/freetype_includes.h"])
     config.add_extension("geometry_utils", 
-                ["yt/utilities/lib/geometry_utils.c"],
+                ["yt/utilities/lib/geometry_utils.pyx"],
                extra_compile_args=['-fopenmp'],
                extra_link_args=['-fopenmp'],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("Interpolators", 
-                ["yt/utilities/lib/Interpolators.c"],
+                ["yt/utilities/lib/Interpolators.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("marching_cubes", 
-                ["yt/utilities/lib/marching_cubes.c",
+                ["yt/utilities/lib/marching_cubes.pyx",
                  "yt/utilities/lib/FixedInterpolator.c"],
                 include_dirs=["yt/utilities/lib/"],
                 libraries=["m"],
@@ -145,35 +145,35 @@ def configuration(parent_package='',top_path=None):
                          "yt/utilities/lib/FixedInterpolator.h",
                 ])
     config.add_extension("misc_utilities", 
-                ["yt/utilities/lib/misc_utilities.c"],
+                ["yt/utilities/lib/misc_utilities.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("Octree", 
-                ["yt/utilities/lib/Octree.c"],
+                ["yt/utilities/lib/Octree.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("png_writer", 
-                ["yt/utilities/lib/png_writer.c"],
+                ["yt/utilities/lib/png_writer.pyx"],
                 define_macros=[("PNG_SETJMP_NOT_SUPPORTED", True)],
                 include_dirs=[png_inc],
                 library_dirs=[png_lib],
                 libraries=["m", "png"],
                 depends=["yt/utilities/lib/fp_utils.pxd"]),
     config.add_extension("PointsInVolume", 
-                ["yt/utilities/lib/PointsInVolume.c"],
+                ["yt/utilities/lib/PointsInVolume.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("QuadTree", 
-                ["yt/utilities/lib/QuadTree.c"],
+                ["yt/utilities/lib/QuadTree.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("RayIntegrators", 
-                ["yt/utilities/lib/RayIntegrators.c"],
+                ["yt/utilities/lib/RayIntegrators.pyx"],
                 libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
     config.add_extension("VolumeIntegrator", 
-               ["yt/utilities/lib/VolumeIntegrator.c",
+               ["yt/utilities/lib/VolumeIntegrator.pyx",
                 "yt/utilities/lib/FixedInterpolator.c",
                 "yt/utilities/lib/kdtree.c"] +
                  glob.glob("yt/utilities/lib/healpix_*.c"), 
                include_dirs=["yt/utilities/lib/"],
                libraries=["m"], 
-               depends = ["yt/utilities/lib/VolumeIntegrator.c",
+               depends = ["yt/utilities/lib/VolumeIntegrator.pyx",
                           "yt/utilities/lib/fp_utils.pxd",
                           "yt/utilities/lib/healpix_interface.pxd",
                           "yt/utilities/lib/endian_swap.h",
@@ -188,7 +188,7 @@ def configuration(parent_package='',top_path=None):
                           "yt/utilities/lib/healpix_vec2pix_nest.c"]
           )
     config.add_extension("grid_traversal", 
-               ["yt/utilities/lib/grid_traversal.c",
+               ["yt/utilities/lib/grid_traversal.pyx",
                 "yt/utilities/lib/FixedInterpolator.c",
                 "yt/utilities/lib/kdtree.c"] +
                  glob.glob("yt/utilities/lib/healpix_*.c"), 
@@ -196,7 +196,7 @@ def configuration(parent_package='',top_path=None):
                libraries=["m"], 
                extra_compile_args=['-fopenmp'],
                extra_link_args=['-fopenmp'],
-               depends = ["yt/utilities/lib/VolumeIntegrator.c",
+               depends = ["yt/utilities/lib/VolumeIntegrator.pyx",
                           "yt/utilities/lib/fp_utils.pxd",
                           "yt/utilities/lib/kdtree.h",
                           "yt/utilities/lib/FixedInterpolator.h",
@@ -205,7 +205,7 @@ def configuration(parent_package='',top_path=None):
                           ]
           )
     config.add_extension("GridTree", 
-    ["yt/utilities/lib/GridTree.c"],
+    ["yt/utilities/lib/GridTree.pyx"],
         libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
 
     if os.environ.get("GPERFTOOLS", "no").upper() != "NO":
@@ -214,7 +214,7 @@ def configuration(parent_package='',top_path=None):
         ldir = os.path.join(gpd, "lib")
         print "INCLUDE AND LIB DIRS", idir, ldir
         config.add_extension("perftools_wrap",
-                ["yt/utilities/lib/perftools_wrap.c"],
+                ["yt/utilities/lib/perftools_wrap.pyx"],
                 libraries=["profiler"],
                 library_dirs = [ldir],
                 include_dirs = [idir],
